# Generated by Django 2.2.4 on 2019-09-05 05:11

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [migrations.swappable_dependency(settings.AUTH_USER_MODEL)]

    operations = [
        migrations.CreateModel(
            name="CredentialOptions",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("challenge", models.TextField()),
                ("username", models.TextField(unique=True)),
                ("display_name", models.TextField()),
                ("ukey", models.TextField(unique=True)),
                ("credential_id", models.TextField()),
                ("sign_count", models.IntegerField(null=True)),
                ("public_key", models.TextField()),
                (
                    "user",
                    models.OneToOneField(
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="credential_options",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        )
    ]
